# load packages (should be done only once)
library("ROpenFLUID")
library('sensitivity')

# definition of the paths and OpenFLUID simulations
OF.dirBase = "/home/crevoisi/OpenFLUID-repository/material/trainings/2014-02/openfluid-practical_fr/datasets/tuto-ropenfluid/"   # directory of OpenFLUID project
OF.dirIn   = paste(OF.dirBase,"IN",sep="")
OF.dirOut  = paste(OF.dirBase,"OUT",sep="")
OF.simu    = OpenFLUID.openDataset(OF.dirIn)  # OpenFLUID simulation
OpenFLUID.setCurrentOutputDir(OF.dirOut)      # directory of output files
OF.deltaT  = OpenFLUID.getDefaultDeltaT(OF.simu)     # time step duration

# define the factors characteristics  :
thetaresSU5 = OpenFLUID.getAttribute(OF.simu,unitclass='SU',unitid=5,attrname='thetares')
thetasatSU5 = OpenFLUID.getAttribute(OF.simu,unitclass='SU',unitid=5,attrname='thetasat')
OF.caractFactor = list(
  name = c("Mean celerity on RS","Initial moisture on SU5","Width of RS3"),
  ref  = as.double(c(0.6,0.3,0.75)),
  inf1 = as.double(c(0.1,thetaresSU5,0.4)),
  sup1 = as.double(c(1.5,thetasatSU5,0.9)),
  inf2 = as.double(c(0.5,thetaresSU5,0.2)),
  sup2 = as.double(c(0.7,thetasatSU5,1.5)),
  inf3 = as.double(c(0.1,thetaresSU5,0.2)),
  sup3 = as.double(c(1.5,thetasatSU5,1.5))
)
OF.bounds1 <- apply(cbind((OF.caractFactor$inf1), (OF.caractFactor$sup1)),MARGIN=1,function(x){list(min=x[1],max=x[2])} )
OF.bounds2 <- apply(cbind((OF.caractFactor$inf2), (OF.caractFactor$sup2)),MARGIN=1,function(x){list(min=x[1],max=x[2])} )
OF.bounds3 <- apply(cbind((OF.caractFactor$inf3), (OF.caractFactor$sup3)),MARGIN=1,function(x){list(min=x[1],max=x[2])} )
