# definition of the function running OpenFLUID with the factors set X
OF.multiRun <- function(X,varOut,nVerb,fast) {
  if (fast) X=as.matrix(X)

  if (varOut=="QH") { out = matrix(data=NA,nrow=nrow(X),ncol=2) }
  else { out = rep(NA,nrow(X)) }
  
  # loop on the lines of the factors vector
  for (i in seq(1:nrow(X))) {

    # screen output of input variables
    if (i %% nVerb == 0) print(paste("simulation no ",as.character(i)," : meancel = ",as.character(X[i,1])," thetaini = ",as.character(X[i,2])," width = ",as.character(X[i,3]),sep=""))
      
    # redefine simulator parameters and input data according to vector X
    OpenFLUID.setSimulatorParam(OF.simu,"water.surf.transfer-rs.hayami","meancel",X[i,1])
    OpenFLUID.setAttribute(OF.simu,"SU",5,"thetaini",X[i,2])
    OpenFLUID.setAttribute(OF.simu,"RS",3,"width",X[i,3])
    
    # run of OpenFLUID with new simulator parameters and input data
    OpenFLUID.addVariablesExportAsCSV(OF.simu,'RS')
    OpenFLUID.runSimulation(OF.simu)

    # choice and screen output of output variables
    if (varOut=="Q") {
      outQ = OpenFLUID.loadResult(OF.simu,"RS",3,"water.surf.Q.downstream-rs")
      out[i] = sum(outQ[,2])*OpenFLUID.getDefaultDeltaT(OF.simu)
      if (i %% nVerb == 0) print(paste("cumulative downstream : ",as.character(sum(outQ[,2])*OpenFLUID.getDefaultDeltaT(OF.simu))," m3",sep=""))
    }
    else if (varOut=="H") {
      outH = OpenFLUID.loadResult(OF.simu,"RS",3,"water.surf.H.level-rs")
      out[i] = max(outH[,2])
      if (i %% nVerb == 0) print(paste("max water level : ",as.character(max(outH[,2]))," m",sep=""))
    }
    else if (varOut=="QH") {
      outQ = OpenFLUID.loadResult(OF.simu,"RS",3,"water.surf.Q.downstream-rs")
      outH = OpenFLUID.loadResult(OF.simu,"RS",3,"water.surf.H.level-rs")
      out[i,1] = max(outH[,2])
      out[i,2] = sum(outQ[,2])*OpenFLUID.getDefaultDeltaT(OF.simu)
      if (i %% nVerb == 0) print(paste("cumulative downstream : ",as.character(sum(outQ[,2])*OpenFLUID.getDefaultDeltaT(OF.simu))," m3 and max water level : ",as.character(max(outH[,2]))," m",sep=""))
    }
  }
  return(out)
}
